@@ -2,16 +2,15 @@
 #' \tabular{ll}{
 #'  \strong{Package:} \tab khroma \cr
 #'  \strong{Type:} \tab Package \cr
-#'  \strong{Version:} \tab 1.1.3 \cr
-#'  \strong{Date:} \tab 2019-06-05 \cr
+#'  \strong{Version:} \tab 1.2.0 \cr
 #'  \strong{License:} \tab GPL-3 \cr
 #'  \strong{DOI:} \tab \href{https://doi.org/10.5281/zenodo.1472077}{10.5281/zenodo.1472077}
 #' }
 #' @author
 #' \strong{Full list of authors and contributors} (alphabetic order)
 #'  \tabular{ll}{
-#'   Nicolas Frerebeau \tab \emph{IRAMAT-CRP2A, Université Bordeaux Montaigne, France} \cr
-#'   Brice Lebrun \tab \emph{CEREGE, Aix-Marseille Université, France}
+#'   Nicolas Frerebeau \tab \emph{Université Bordeaux Montaigne, France} \cr
+#'   Brice Lebrun \tab \emph{Aix-Marseille Université, France}
 #'  }
 #'
 #' \strong{Package maintainer}
@@ -29,9 +28,3 @@
 #' @docType package
 #' @keywords internal
 "_PACKAGE"
-
-# The following block is used by usethis to automatically manage
-# roxygen namespace tags. Modify with care!
-## usethis namespace: start
-## usethis namespace: end
-NULL
