@@ -9,8 +9,8 @@ soil <- data.frame(
   )
 )
 
-ggplot(soil, aes(fill = name)) +
-  geom_rect(aes(xmin = rep(0, 24), xmax = rep(1, 24),
-                ymin = 1:24, ymax = 1:24+1)) +
-  scale_y_reverse() +
-  khroma::scale_fill_soil(name = "Soil")
+ggplot2::ggplot(soil, ggplot2::aes(fill = name)) +
+  ggplot2::geom_rect(aes(xmin = rep(0, 24), xmax = rep(1, 24),
+                         ymin = 1:24, ymax = 1:24+1)) +
+  ggplot2::scale_y_reverse() +
+  scale_fill_soil(name = "Soil")
